diff --git a/_posts/Index/Category/0000-01-01-Character-Creation.html b/_posts/Index/Category/0000-01-01-Character-Creation.html
index 8225c5a..f860730 100644
--- a/_posts/Index/Category/0000-01-01-Character-Creation.html
+++ b/_posts/Index/Category/0000-01-01-Character-Creation.html
@@ -127,8 +127,26 @@ tags: [ Rules ]
+
Character Background Index
+
+
Adventuring Company Index
-
+
|
diff --git a/_posts/Index/Publication/0000-01-01-No-Quarter-66.html b/_posts/Index/Publication/0000-01-01-No-Quarter-66.html
new file mode 100644
index 0000000..9461f39
--- /dev/null
+++ b/_posts/Index/Publication/0000-01-01-No-Quarter-66.html
@@ -0,0 +1,36 @@
+---
+title: "No Quarter #66"
+published: true
+layout: ikrpg
+categories: [ Index, Publication ]
+tags: [ Rules ]
+---
+
+
+ Back to the Full Publication Index.
+
+
+No Quarter #66 Index
+
+
+
+
+
\ No newline at end of file
diff --git a/ikrpg.appcache b/ikrpg.appcache
index 369890f..14a67f6 100644
--- a/ikrpg.appcache
+++ b/ikrpg.appcache
@@ -136,6 +136,7 @@ CACHE:
/index/publication/No-Quarter-63/
/index/publication/No-Quarter-64/
/index/publication/No-Quarter-65/
+/index/publication/No-Quarter-66/
/index/publication/Path-of-Devastation-Season-1/
/index/publication/Path-of-Devastation-Season-2/
/index/publication/Path-of-Devastation-Season-3/
diff --git a/index.html b/index.html
index 3bc6c0a..c95816d 100644
--- a/index.html
+++ b/index.html
@@ -131,6 +131,7 @@ tags: [ Version 4 ]
#63
#64
#65
+ #66
)
Path of Devastation (
- Season 1
diff --git a/static/javascripts/index.js b/static/javascripts/index.js
index 59230c3..a14cde0 100644
--- a/static/javascripts/index.js
+++ b/static/javascripts/index.js
@@ -14,7 +14,7 @@ var ikrpg = ikrpg || {};
// Alchemy
// Alchemical Ingredient, Alchemical Item, Field Alchemy, Grenate
// Character Creation
// Adventuring Company, Archetype, Career, Career Option, Race, Scorne Caste
// Armory
// Armor, Melee Weapon, Improvised Melee Weapon, Ranged Weapon, Ammunition,
// Ranged Weapon Accessory, Improvised Ranged Weapon, Magical Ranged Weapon, Trap
@@ -9470,6 +9470,47 @@ var ikrpg = ikrpg || {};
subcategory: "Race",
game: "IKU"
},
+ // ##### Character Creation > Character Background ##### \\
+ {
+ name: "Civil War Veteran",
+ publication: "No Quarter #66",
+ page: "106",
+ category: "Character Creation",
+ subcategory: "Character Background",
+ game: "FMF"
+ },
+ {
+ name: "Dragon-Marked",
+ publication: "No Quarter #66",
+ page: "106",
+ category: "Character Creation",
+ subcategory: "Character Background",
+ game: "FMF"
+ },
+ {
+ name: "Hammer Veteran",
+ publication: "No Quarter #66",
+ page: "107",
+ category: "Character Creation",
+ subcategory: "Character Background",
+ game: "FMF"
+ },
+ {
+ name: "Lord of Umbrey",
+ publication: "No Quarter #66",
+ page: "108",
+ category: "Character Creation",
+ subcategory: "Character Background",
+ game: "FMF"
+ },
+ {
+ name: "Vanquished Soldier",
+ publication: "No Quarter #66",
+ page: "107",
+ category: "Character Creation",
+ subcategory: "Character Background",
+ game: "FMF"
+ },
// ##### Character Creation > Skorne Caste ##### \\
{
name: "Extoller",
@@ -14,7 +14,7 @@ var ikrpg = ikrpg || {};
// Alchemical Ingredient, Alchemical Item, Field Alchemy, Grenate
// Character Creation
- // Adventuring Company, Archetype, Career, Career Option, Race, Scorne Caste
+ // Adventuring Company, Archetype, Career, Career Option, Race, Character Background, Skorne Caste
// Armory
// Armor, Melee Weapon, Improvised Melee Weapon, Ranged Weapon, Ammunition,